@@ -122,30 +122,26 @@ applet_pixel_size_changed_cb(GtkWidget *widget, int size, gpointer data)
 {
     PanelApplet *applet = data;
     properties *prop;
-    static int counter = 0;
 
     prop = g_object_get_data (G_OBJECT (applet), "prop");
    
-    if(counter++ > 0)
 	show_message((gchar *) _("size changed")); 
 
     prop->normal_size_y = size;
     if(size <= GNOME_Vertigo_PANEL_X_SMALL)
 	{
-	  if(counter > 1) /* ignore size-changed-signal at startup */
-	      prop->show_frame = FALSE;
+	    prop->show_frame = FALSE;
 	    prop->flat_layout = TRUE;
 	} 
     else if(size <= GNOME_Vertigo_PANEL_SMALL)
 	{
-	    if(counter > 1) /* ignore size-changed-signal at startup */
-	      prop->show_frame = TRUE;
+
+	    prop->show_frame = TRUE;
 	    prop->flat_layout = TRUE;
 	} 
     else
 	{
-	    if(counter > 1) /* ignore size-changed-signal at startup */
-	      prop->show_frame = TRUE;
+	    prop->show_frame = TRUE;
 	    prop->flat_layout = FALSE;
 	}
 
@@ -166,6 +162,7 @@ redraw_applet(PanelApplet *applet)
     GtkWidget *handle;
     GtkWidget *icon;
     GtkWidget *vbox;
+    GtkTooltips *tooltips;
     int size_frames = 0;
     int size_status_line = 18;
 
@@ -173,6 +170,8 @@ redraw_applet(PanelApplet *applet)
     static GtkWidget *applet_inner_vbox = NULL;
     static int first_time = TRUE;   
     
+    tooltips = gtk_tooltips_new ();
+    
     prop = g_object_get_data (G_OBJECT (applet), "prop");
 
     /* recalculate sizes */
@@ -244,11 +243,8 @@ redraw_applet(PanelApplet *applet)
     gtk_widget_set_usize(GTK_WIDGET(button), 13, 10);
     icon = gnome_pixmap_new_from_xpm_d (browser_mini_xpm);
     gtk_container_add(GTK_CONTAINER(button), icon);
-#if 0 /* FIXME */
-    applet_widget_set_widget_tooltip(APPLET_WIDGET(applet),
-				     GTK_WIDGET(button),
-				     _("Browser"));
-#endif
+
+    gtk_tooltips_set_tip (tooltips, button, _("Browser"), NULL);
     gtk_box_pack_start(GTK_BOX(hbox_buttons), button, TRUE, TRUE, 0);
 
     /* add history button */
@@ -259,11 +255,8 @@ redraw_applet(PanelApplet *applet)
     gtk_widget_set_usize(GTK_WIDGET(button), 13, 10);
     icon = gnome_pixmap_new_from_xpm_d (history_mini_xpm);
     gtk_container_add(GTK_CONTAINER(button), icon);
-#if 0 /* FIXME */
-    applet_widget_set_widget_tooltip(APPLET_WIDGET(applet),
-				     GTK_WIDGET(button),
-				     _("History"));
-#endif
+
+    gtk_tooltips_set_tip (tooltips, button, _("History"), NULL);
     gtk_box_pack_end(GTK_BOX(hbox_buttons), button, TRUE, TRUE, 0);
 
     /* add buttons into frame */
@@ -339,9 +332,6 @@ redraw_applet(PanelApplet *applet)
     gtk_box_pack_start(GTK_BOX(applet_vbox), applet_inner_vbox, TRUE, TRUE, 0);
 
     if(first_time)
-#if 0
-	applet_widget_add (APPLET_WIDGET (applet), applet_vbox);
-#endif
         gtk_container_add(GTK_CONTAINER(applet), applet_vbox);
     first_time = FALSE;
 
@@ -383,7 +373,7 @@ mini_commander_applet_fill(PanelApplet *applet)
     /*we have to bind change_pixel_size before we do applet_widget_add 
       since we need to get an initial change_pixel_size signal to set our
       initial size, and we get that during the _add call*/
-    g_signal_connect(G_OBJECT(applet),
+	g_signal_connect(G_OBJECT(applet),
 		     "change_size",
 		     G_CALLBACK(applet_pixel_size_changed_cb),
 		     applet);
@@ -394,8 +384,8 @@ mini_commander_applet_fill(PanelApplet *applet)
     g_signal_connect(G_OBJECT(applet), "destroy",
 		     G_CALLBACK(applet_destroy_signal),
 		     applet); 
-    
-    redraw_applet(applet);
+
+    applet_pixel_size_changed_cb(NULL, panel_applet_get_size (applet), applet);
 
     panel_applet_setup_menu_from_file (applet,
 			    NULL, /* opt. datadir */
